# py_challenges



## Prerequisites

- Python package manager: `pipx` (recommended) or `pip`
- For building the app: `poetry`


## Installation 

```bash
pipx install 2rage-py-challenges
```

or

```bash
pip install 2rage-py-challenges
```

## Run

- `search-methods` 
- `lixical-analyzer`


## Docs


| Path | Content |
| ---- | ------- |
| `lixical_analyzer/*` | Implementation of a Lexical Analyzer Based on Finite Automata |
| `search_methods/*` | Performance analysis of linear probing and binary search tree |